@@ -47,6 +47,23 @@ def decide():
     writetable = params['writetable']
     rankby = params['rankby']
 
+    if table != "" and not dontwrite:
+
+        with open("log.txt", 'w') as f:
+            f.write("Input: " + table + "\n")
+            f.write("Fragment: " + str(fraglen) + "\n")
+            f.write("Overlap: " + str(overlap) + "\n")
+            if dimerize:
+                f.write("Dimerized: " + dimerize + "\n")
+            elif dimerize_all:
+                f.write("Dimerized all proteins\n")
+            elif dimerize_except:
+                f.write("Dimerize all except: " + dimerize_except + "\n")
+            if consider != "":
+                f.write("Consider: " + consider + "\n")
+            f.write("Alphafold executable: " + alphafold_exec + "\n")
+
+
     ##################################
     #Parse input
 
@@ -69,7 +86,7 @@ def decide():
     if writetable:
         print("\n>> Parsing results...")
         df = analyze.getscores(rankby)
-        analyze.write_top(df, 0)
+        analyze.write_top(df, 0, rankby)
         sys.exit()
 
     ##################################
@@ -77,10 +94,17 @@ def decide():
     if threshold != -1:
         print("\n>> Parsing results...")
         df = analyze.getscores(rankby)
+        
         if df.empty:
             sys.exit("\n>> Error: no results could be found.\n")
-        elif df[df[rankby]>threshold].empty:
+        try:
+            df[df[rankby]>threshold]
+        except TypeError:
+            sys.exit("\n>> Error: some values you want to rank by don't seem to exist. Did you try to rank by iptm without those scores existing?\n")
+
+        if df[df[rankby]>threshold].empty:
             sys.exit("\n>> Error: no results could be found with "+rankby+" above " + str(threshold) + ".\n")
+
         analyze.summarize_pae_pdf(df, threshold, rankby)
         analyze.write_top(df, threshold, rankby)
         analyze.write_modelpngs(df, threshold, rankby, overwrite=overwrite)
